@@ -1,5 +1,6 @@
 from pychonet.EchonetInstance import EchonetInstance
 
+
 class StorageBattery(EchonetInstance):
 
     WORKING_OPERATION_STATES = {
@@ -11,13 +12,15 @@ class StorageBattery(EchonetInstance):
         0x45: "Test",
         0x46: "Automatic",
         0x48: "Restart",
-        0x49: "Effective capacity recalculation processing"
+        0x49: "Effective capacity recalculation processing",
     }
 
-    def __init__(self, host, api_connector = None, instance = 0x1):
+    def __init__(self, host, api_connector=None, instance=0x1):
         self._eojgc = 0x02
-        self._eojcc = 0x7d
-        EchonetInstance.__init__(self, host, self._eojgc, self._eojcc, instance, api_connector)
+        self._eojcc = 0x7D
+        EchonetInstance.__init__(
+            self, host, self._eojgc, self._eojcc, instance, api_connector
+        )
 
     def getRemainingStoredElectricity3(self):
         return self.getMessage(0xE4)
